# Contributing Guidelines

This started out as personal challenge to figure out how to build a feature-complete extension module for Python. Bug
reports are welcome! So are bug fixes, but be advised that responses may be delayed (I won't have much free time), and
that large pull requests may be closed without a review.

Architectural and design changes will be deferred until the project has reached a mature, production-ready state.

So, just be cool (optional).
